
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: envoy.dependency.pip_check:package

from setuptools import setup

setup(**{
    'author': 'Ryan Northey',
    'author_email': 'ryan@synca.io',
    'description': '"Pip dependabot checker used in Envoy proxy\'s CI"',
    'entry_points': {
        'console_scripts': [
            'envoy.dependency.pip_check=envoy.dependency.pip_check:cmd',
        ],
    },
    'install_requires': (
        'abstracts>=0.0.12',
        'envoy.base.checker>=0.0.2',
        'envoy.base.utils>=0.0.12',
    ),
    'license': 'Apache Software License 2.0',
    'long_description': """
envoy.dependency.pip_check
==========================

Pip dependabot checker used in Envoy proxy's CI
""",
    'maintainer': 'Ryan Northey',
    'maintainer_email': 'ryan@synca.io',
    'name': 'envoy.dependency.pip_check',
    'namespace_packages': (
    ),
    'package_data': {
        'envoy.dependency.pip_check': (
            'py.typed',
        ),
    },
    'packages': (
        'envoy.dependency.pip_check',
    ),
    'url': 'https://github.com/envoyproxy/pytooling/tree/main/envoy.dependency.pip_check',
    'version': '0.0.5',
})
